import React, { Component } from 'react';
import { PullToRefresh, Modal, Toast, TextareaItem } from 'antd-mobile';
import styles from './style.css';
import PublicCarItem from '../PublicCar/components/PublicCarItem';
import { fetchApplyPublicCarList, dealPublicCar } from '../../api/index';

class PublicCarDeal extends Component {
  constructor(props) {
    super(props);
    this.state = {
      refreshing: false,
      down: true,
      height: document.documentElement.clientHeight,
      pagination: {
        pageNum: 1,
        pageSize: 50,
      },
      list: [],
      dealDialogVisible: false,
      selected: {
        id: '',
        value: '',
        carPlate: '',
        dealOpinion: '',
      },
    };
  }
  componentDidMount() {
    this.fetchList();
  }
  fetchList = () => {
    const { pagination } = this.state;
    fetchApplyPublicCarList({
      ...pagination,
    }).then(res => {
      // const { list, ...pagination } = res.data;
      // this.setState({
      //   list: list,
      //   pagination: pagination,
      // });
      this.setState({
        list: res.data.map(i => ({
          ...i,
          dealResult: 1,
        })),
      });
    });
  };
  refreshHandle = () => {
    this.fetchList();
  };
  toggleSelectedState = val => {
    this.setState({
      selected: val,
    });
  };
  dealHandle = id => {
    this.setState(({ selected }) => ({
      dealDialogVisible: true,
      selected: {
        ...selected,
        id,
      },
    }));
  };
  resetDialog = () => {};
  toggleSelectedState = val => {
    this.setState(({ selected }) => ({
      selected: {
        ...selected,
        value: val,
      },
    }));
  };
  submitHandle = () => {
    const {
      selected: { id, value, carPlate, dealOpinion },
    } = this.state;
    const entity =
      value === 1
        ? {
            id: id,
            dealResult: value,
            carPlate: carPlate,
          }
        : {
            id: id,
            dealResult: value,
            dealOpinion: dealOpinion,
          };
    dealPublicCar(entity)
      .then(res => {
        Toast.fail(res.msg || '处理成功！');
      })
      .catch(err => {
        Toast.fail(err.msg || '处理失败！');
      });
  };
  render() {
    const {
      selected: { value, carPlate, dealOpinion },
      dealDialogVisible,
    } = this.state;
    return (
      <PullToRefresh
        damping={60}
        ref={el => (this.ptr = el)}
        style={{
          height: this.state.height,
          overflow: 'auto',
        }}
        indicator={{ deactivate: '上拉可以刷新' }}
        direction={'up'}
        refreshing={this.state.refreshing}
        onRefresh={this.refreshHandle}
      >
        <div className={styles.listInfo}>显示最近半年的报修记录</div>
        {this.state.list.length ? (
          this.state.list.map(i => (
            <PublicCarItem key={i.id} data={i} dealHandle={this.dealHandle} />
          ))
        ) : (
          <div className={styles.noData}>暂无数据</div>
        )}
        <Modal
          className={styles.dealDialog}
          visible={dealDialogVisible}
          transparent
          maskClosable={false}
          onClose={this.resetDialog}
          title=""
          footer={[
            { text: '放弃', onPress: () => console.log('cancel') },
            {
              text: '提交',
              onPress: this.submitHandle,
            },
          ]}
        >
          <div key="radio" className={styles.alertInfo}>
            <div
              className={styles.radioBox}
              onClick={() => this.toggleSelectedState(1)}
            >
              <span className={styles.checkLabel}>
                <span className={value === 1 ? styles.checkInner : ''} />
              </span>
              <span>同意</span>
            </div>
            <div
              className={styles.radioBox}
              onClick={() => this.toggleSelectedState(2)}
            >
              <span className={styles.checkLabel}>
                <span className={value === 2 ? styles.checkInner : ''} />
              </span>
              <span>不同意</span>
            </div>
          </div>
          {value === 1 ? (
            <div key="agree" className={styles.agree}>
              <span className={styles.dialogLabel}>派车车牌</span>
            </div>
          ) : value === 2 ? (
            <div key="notAgree" className={styles.notAgree}>
              <span className={styles.dialogLabel}>处理结果</span>
              <TextareaItem
                className={styles.textarea}
                placeholder="输入报修地址"
                rows={3}
                count={50}
                // value={dealOpinion}
              />
            </div>
          ) : null}
        </Modal>
      </PullToRefresh>
    );
  }
}

export default PublicCarDeal;
